import axios from "axios";
import * as urls from './urls.js';
import { Accounts } from "./accounts.js";

axios.defaults.withCredentials = true;

class Client
{
    /**
     * Create a client to interract with the api
     *
     * @param {string} url - The url of the backend
    */
    constructor(url)
    {
        /**
         * The axios client
         * @type AxiosInstance */
        this._client = axios.create({
            baseURL: url,
            headers: {
                'Content-Type': 'application/json'
            }
        });

        this.accounts = new Accounts(this);
    }

    /**
     * return if the client is logged
    */
    get isAuthentificate()
    {
        return this.token != undefined;
    }

    /**
     * A no consummer function to send get requests
     *
     * @param {string} uri - The path want to get
    */
    async _get(uri)
    {
        let response = this._client.get(uri);
        return response;
    }

    /**
     * A no consummer function to send post requests
     * @param {string} uri - The path want to post
     * @type {AxiosInstance}- The path want to post
    */
    async _post(uri, data)
    {
        /**
         * The axios client
         * @type AxiosInstance */
        let response = this._client.post(uri, data).catch(() => {});
        return response;
    }

    /**
     * Login your client with username and password
     *
     * @param {string} username - The username of the client
     * @param {string} password - The password of the client
    */
    async login(username, password)
    {
        let response = this._post(urls.accounts_login, {'username': username, 'password': password})
        return response;
    }
}

let url = "http://0.0.0.0:8000/"

let client = new Client(url)

let response1 = await client.accounts.create("bozoman", "man")
let response2 = await client?.login("bozoman", "man")

//console.log(response1.data)

export { Client }